@@ -44,13 +44,11 @@ class JSONStore(object):
         Main dispatcher.
 
         Dispatch is done by HTTP method. It is possible to override the method using
-        the parameter ``method`` in the URL; for example::
-
-            http://localhost:8081/?method=DELETE
+        the ``X-HTTP-Method-Override`` header.
 
         """
         req = Request(environ)
-        method = req.GET.get('method') or req.method
+        method = req.headers.get('X-HTTP-Method-Override') or req.method
         func = getattr(self, method)
         res = func(req)
         return res(environ, start_response)
